import * as React from 'react';
import { DashboardTile } from "./DashboardTile";
import { ControlDisplayDensity } from "igniteui-react-core";
import { BaseControlTheme } from "igniteui-react-core";
import { IgrDashboardTileFilterStringErrorsParsingEventArgs } from "./igr-dashboard-tile-filter-string-errors-parsing-event-args";
import { ICommandStateChangedListener } from "igniteui-react-core";
import { ICommandAvailabilityListener } from "igniteui-react-core";
import { ToolActionInfo } from "igniteui-react-core";
import { DashboardTileVisualizationType } from "./DashboardTileVisualizationType";
import { CrosshairsDisplayMode } from "igniteui-react-charts";
import { IgrValueModeCollection } from "igniteui-react-charts";
import { IgrChartSelectedItemCollection } from "igniteui-react-charts";
import { SeriesHighlightedValuesDisplayMode } from "igniteui-react-core";
import { TrendLineType } from "igniteui-react-core";
import { IgrDashboardTileSummaryDescriptionCollection } from "./igr-dashboard-tile-summary-description-collection";
import { IgrFilterExpressionCollection } from "igniteui-react-core";
import { IgrDashboardTileSortDescriptionCollection } from "./igr-dashboard-tile-sort-description-collection";
import { IgrDashboardTileCustomization } from "./igr-dashboard-tile-customization";
import { IgrDashboardTileCustomizationCollection } from "./igr-dashboard-tile-customization-collection";
import { IgrDashboardTileChangingContentEventArgs } from "./igr-dashboard-tile-changing-content-event-args";
export declare class IgrDashboardTile extends React.Component<IIgrDashboardTileProps> {
    private _container;
    private _initialized;
    private _elRef;
    private _portalManager;
    private _wrapper;
    private _height;
    private _width;
    set height(value: string);
    get height(): string;
    set width(value: string);
    get width(): string;
    private _getMainRef;
    render(): React.DetailedReactHTMLElement<{
        className: string;
        ref: (ref: any) => void;
        children: any[];
    }, any>;
    private requestRender;
    constructor(props: IIgrDashboardTileProps);
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    protected initializeProperties(): void;
    updateStyle(): void;
    destroy(): void;
    componentWillUnmount(): void;
    componentDidMount(): void;
    initializeContent(): void;
    protected createImplementation(): DashboardTile;
    protected _implementation: any;
    protected mounted: boolean;
    get nativeElement(): HTMLElement;
    /**
     * @hidden
     */
    get i(): DashboardTile; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrDashboardTile;
    private _DashboardTile;
    private _customizations;
    private _actualCustomizations;
    get actualCustomizations(): IgrDashboardTileCustomization[];
    private _contentCustomizations;
    get contentCustomizations(): IgrDashboardTileCustomization[];
    private _customizationsAdapter;
    /**
     * Gets a collection where you can add customization that will be applied to the generated visualizations.
    */
    get customizations(): IgrDashboardTileCustomizationCollection;
    /**
     * Gets or sets text to display above the plot area.
    */
    get tileTitle(): string;
    set tileTitle(v: string);
    /**
     * Gets the initial sorts that are applied to the chart.
    */
    get initialSortDescriptions(): IgrDashboardTileSortDescriptionCollection;
    /**
     * Gets the initial sorts that are applied to the chart after groupings and summaries are applied.
    */
    get initialGroupSortDescriptions(): IgrDashboardTileSortDescriptionCollection;
    /**
     * Gets the initial groupings that are applied to the chart.
    */
    get initialGroupDescriptions(): IgrDashboardTileSortDescriptionCollection;
    /**
     * Gets the initial filters that are applied to the chart.
    */
    get initialFilterExpressions(): IgrFilterExpressionCollection;
    /**
     * Gets the initial highlight filters that are applied to the chart.
    */
    get initialHighlightFilterExpressions(): IgrFilterExpressionCollection;
    /**
     * Gets the initial summaries that are applied to the chart.
    */
    get initialSummaryDescriptions(): IgrDashboardTileSummaryDescriptionCollection;
    /**
     * Gets or sets the sorts to apply to the chart. This property will become ignored if sorts are changed outside of this property.
    */
    get initialSorts(): string;
    set initialSorts(v: string);
    /**
     * Gets or sets the sorts to apply after grouping has been applied.
    */
    get groupSorts(): string;
    set groupSorts(v: string);
    /**
     * Gets or sets the groupings to apply to the chart. This property will become ignored if sorts are changed outside of this property.
    */
    get initialGroups(): string;
    set initialGroups(v: string);
    /**
     * Gets or sets the filter to apply to the chart. This property will become ignored if the filter is changed outside of this property.
    */
    get initialFilter(): string;
    set initialFilter(v: string);
    /**
     * Gets or sets the filter to apply to the chart. This property will become ignored if the filter is changed outside of this property.
    */
    get initialHighlightFilter(): string;
    set initialHighlightFilter(v: string);
    /**
     * Gets or sets the summaries to apply to the chart. This property will become ignored if sorts are changed outside of this property.
    */
    get initialSummaries(): string;
    set initialSummaries(v: string);
    /**
     * Gets the current sort that is applied to the grid. Collection can be updated to modify the sort for the grid. Once sort descriptions are in this collection, the grid will no longer listen for changes on their properties.
    */
    get sortDescriptions(): IgrDashboardTileSortDescriptionCollection;
    get groupSortDescriptions(): IgrDashboardTileSortDescriptionCollection;
    /**
     * Gets the current grouping that is applied to the grid. Collection can be updated to modify the grouping for the grid. Once grouping descriptions are in this collection, the grid will no longer listen for changes on their properties.
    */
    get groupDescriptions(): IgrDashboardTileSortDescriptionCollection;
    /**
     * Gets the current filter that is applied to the chart. Collection can be updated to modify the filter for the chart. Once filter expressions are in this collection, the chart will no longer listen for changes on their properties.
    */
    get filterExpressions(): IgrFilterExpressionCollection;
    /**
     * Gets the current highlight filter that is applied to the chart. Collection can be updated to modify the highlight filter for the chart. Once filter expressions are in this collection, the chart will no longer listen for changes on their properties.
    */
    get highlightFilterExpressions(): IgrFilterExpressionCollection;
    /**
     * Gets the current summaries that are applied to the grid.
    */
    get summaryDescriptions(): IgrDashboardTileSummaryDescriptionCollection;
    /**
     * Gets or sets a collection of data items used to generate the dashboard tile.
     * The ItemsSource of this dashboard tile can be a list of objects containing one or more numeric properties.
     * Additionally, if the objects in the list implement an enumerable interface,
     * the dashboard tile will attempt to delve into the sub-collections when reading through the data source.
     * Data binding can be further configured by attributing the data item classes
     * with the data intent feature.
    */
    get dataSource(): any;
    set dataSource(v: any);
    /**
     * Gets or sets a collection of data items used to generate the dashboard tile.
     * The HighlightedItemsSource of this dashboard tile can be a list of objects containing one or more numeric properties.
     * Additionally, if the objects in the list implement an enumerable interface,
     * the dashboard tile will attempt to delve into the sub-collections when reading through the data source.
     * Data binding can be further configured by attributing the data item classes
     * with the data intent feature.
    */
    get highlightedDataSource(): any;
    set highlightedDataSource(v: any);
    /**
     * Gets or sets whether the dashboard tile should display mock data when the data source has not been provided, if supported for this type of chart.
    */
    get shouldDisplayMockData(): boolean;
    set shouldDisplayMockData(v: boolean);
    /**
     * Gets or sets whether annotations for the final value of each series is displayed on the axis.
    */
    get shouldAvoidAxisAnnotationCollisions(): boolean;
    set shouldAvoidAxisAnnotationCollisions(v: boolean);
    /**
     * Gets or sets the formula used for calculating trend lines in this chart.
     * This property applies only to these chart types: point, line, spline, and bubble
    */
    get trendLineType(): TrendLineType;
    set trendLineType(v: TrendLineType);
    /**
     * Gets or sets whether the dashboard tile should use a faded skeleton style for mock data.
    */
    get shouldUseSkeletonStyleForMockData(): boolean;
    set shouldUseSkeletonStyleForMockData(v: boolean);
    /**
     * Gets or sets whether and how to display highlighted values for the series. Note, this is distinct from the highlighting feature that indicates what is closest or under the mouse.
     * This property applies to Category Chart and Financial Chart controls.
    */
    get highlightedValuesDisplayMode(): SeriesHighlightedValuesDisplayMode;
    set highlightedValuesDisplayMode(v: SeriesHighlightedValuesDisplayMode);
    /**
     * Gets or sets a set of property paths that should be included for consideration by the category chart, leaving the remainder excluded. If null, all properties will be considered.
    */
    get includedProperties(): string[];
    set includedProperties(v: string[]);
    /**
     * Gets the current set of valid visualization types for the data.
    */
    get validVisualizationTypes(): DashboardTileVisualizationType[];
    set validVisualizationTypes(v: DashboardTileVisualizationType[]);
    /**
     * Gets or sets a set of property paths that should be excluded from consideration by the category chart.
    */
    get excludedProperties(): string[];
    set excludedProperties(v: string[]);
    /**
     * Gets or sets the palette of brushes to use for coloring the dashboard tile.
     * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
    */
    get brushes(): string[];
    set brushes(v: string[]);
    /**
     * Gets or sets the palette of brushes to use for outlines on the dashboard tile.
     * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
    */
    get outlines(): string[];
    set outlines(v: string[]);
    private _selectedSeriesItems;
    /**
     * Gets the currently selected data items.  Adding or removing data items from this collection will
     * select or deselect the visuals associated with those items.
    */
    get selectedSeriesItems(): IgrChartSelectedItemCollection;
    set selectedSeriesItems(v: IgrChartSelectedItemCollection);
    /**
     * Gets the actual palette of brushes to use for coloring the chart series.
    */
    get actualBrushes(): string[];
    set actualBrushes(v: string[]);
    /**
     * Gets the actual palette of brushes to use for outlines on the chart series.
    */
    get actualOutlines(): string[];
    set actualOutlines(v: string[]);
    /**
     * Gets the brush to use for the Category axis major strokes, if applicable.
    */
    get categoryAxisMajorStroke(): string;
    set categoryAxisMajorStroke(v: string);
    private _valueLines;
    /**
     * Gets or sets what value lines to use in the chart.
    */
    get valueLines(): IgrValueModeCollection;
    set valueLines(v: IgrValueModeCollection);
    /**
     * Gets or sets the palette of brushes to use for coloring the value lines present in the ValueLines property.
     * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
    */
    get valueLinesBrushes(): string[];
    set valueLinesBrushes(v: string[]);
    /**
     * Gets or sets if the auto value callouts should be displayed.
    */
    get autoCalloutsVisible(): boolean;
    set autoCalloutsVisible(v: boolean);
    /**
     * Gets or sets whether annotations are shown along the axis for crosshair values
    */
    get crosshairsAnnotationEnabled(): boolean;
    set crosshairsAnnotationEnabled(v: boolean);
    /**
     * Gets or sets whether annotations for the final value of each series is displayed on the axis.
    */
    get finalValueAnnotationsVisible(): boolean;
    set finalValueAnnotationsVisible(v: boolean);
    /**
     * Gets or sets the crosshairs to be displayed.
    */
    get crosshairsDisplayMode(): CrosshairsDisplayMode;
    set crosshairsDisplayMode(v: CrosshairsDisplayMode);
    /**
     * Gets or sets the crosshairs to be displayed.
    */
    get visualizationType(): DashboardTileVisualizationType;
    set visualizationType(v: DashboardTileVisualizationType);
    /**
     * Gets or sets the crosshairs to be displayed.
    */
    get validVisualizationTypePriorityThreshold(): number;
    set validVisualizationTypePriorityThreshold(v: number);
    /**
     * Gets or sets the base built in theme to use for the checkbox.
    */
    get baseTheme(): BaseControlTheme;
    set baseTheme(v: BaseControlTheme);
    /**
     * Gets or sets the display density to use for the toolbar.
    */
    get density(): ControlDisplayDensity;
    set density(v: ControlDisplayDensity);
    /**
     * Gets or sets the color to use for the background of the component.
    */
    get backgroundColor(): string;
    set backgroundColor(v: string);
    get isVisTypeStacked(): boolean;
    get isVisTypeRadial(): boolean;
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    updateSettingsValue(key: string, value: any): void;
    getSettingsValue(key: string): any;
    hasModifiedSettings(): boolean;
    clearSettings(): void;
    removeSettingsValue(key: string): void;
    zoomIn(percentage: number): void;
    /**
     * Performs zoom out action on the chart by specified percentage of current window rect
    
    */
    zoomOut(percentage: number): void;
    /**
     * Resets the zoom level to default.
    
    */
    resetZoom(): void;
    onUIReady(): void;
    getDesiredToolbarActions(): ToolActionInfo[];
    addCommandAvailabilityListener(listener: ICommandAvailabilityListener): void;
    removeCommandAvailabilityListener(listener: ICommandAvailabilityListener): void;
    addCommandStateChangedListener(listener: ICommandStateChangedListener): void;
    removeCommandStateChangedListener(listener: ICommandStateChangedListener): void;
    private _changingContent;
    private _changingContent_wrapped;
    get changingContent(): (s: IgrDashboardTile, e: IgrDashboardTileChangingContentEventArgs) => void;
    set changingContent(ev: (s: IgrDashboardTile, e: IgrDashboardTileChangingContentEventArgs) => void);
    private _filterStringErrorsParsing;
    private _filterStringErrorsParsing_wrapped;
    get filterStringErrorsParsing(): (s: IgrDashboardTile, e: IgrDashboardTileFilterStringErrorsParsingEventArgs) => void;
    set filterStringErrorsParsing(ev: (s: IgrDashboardTile, e: IgrDashboardTileFilterStringErrorsParsingEventArgs) => void);
}
export interface IIgrDashboardTileProps {
    width?: string;
    height?: string;
    children?: React.ReactNode;
    /**
 * Gets or sets text to display above the plot area.
*/
    tileTitle?: string;
    /**
     * Gets or sets the sorts to apply to the chart. This property will become ignored if sorts are changed outside of this property.
    */
    initialSorts?: string;
    /**
     * Gets or sets the sorts to apply after grouping has been applied.
    */
    groupSorts?: string;
    /**
     * Gets or sets the groupings to apply to the chart. This property will become ignored if sorts are changed outside of this property.
    */
    initialGroups?: string;
    /**
     * Gets or sets the filter to apply to the chart. This property will become ignored if the filter is changed outside of this property.
    */
    initialFilter?: string;
    /**
     * Gets or sets the filter to apply to the chart. This property will become ignored if the filter is changed outside of this property.
    */
    initialHighlightFilter?: string;
    /**
     * Gets or sets the summaries to apply to the chart. This property will become ignored if sorts are changed outside of this property.
    */
    initialSummaries?: string;
    /**
     * Gets or sets a collection of data items used to generate the dashboard tile.
     * The ItemsSource of this dashboard tile can be a list of objects containing one or more numeric properties.
     * Additionally, if the objects in the list implement an enumerable interface,
     * the dashboard tile will attempt to delve into the sub-collections when reading through the data source.
     * Data binding can be further configured by attributing the data item classes
     * with the data intent feature.
    */
    dataSource?: any;
    /**
     * Gets or sets a collection of data items used to generate the dashboard tile.
     * The HighlightedItemsSource of this dashboard tile can be a list of objects containing one or more numeric properties.
     * Additionally, if the objects in the list implement an enumerable interface,
     * the dashboard tile will attempt to delve into the sub-collections when reading through the data source.
     * Data binding can be further configured by attributing the data item classes
     * with the data intent feature.
    */
    highlightedDataSource?: any;
    /**
     * Gets or sets whether the dashboard tile should display mock data when the data source has not been provided, if supported for this type of chart.
    */
    shouldDisplayMockData?: boolean | string;
    /**
     * Gets or sets whether annotations for the final value of each series is displayed on the axis.
    */
    shouldAvoidAxisAnnotationCollisions?: boolean | string;
    /**
     * Gets or sets the formula used for calculating trend lines in this chart.
     * This property applies only to these chart types: point, line, spline, and bubble
    */
    trendLineType?: TrendLineType | string;
    /**
     * Gets or sets whether the dashboard tile should use a faded skeleton style for mock data.
    */
    shouldUseSkeletonStyleForMockData?: boolean | string;
    /**
     * Gets or sets whether and how to display highlighted values for the series. Note, this is distinct from the highlighting feature that indicates what is closest or under the mouse.
     * This property applies to Category Chart and Financial Chart controls.
    */
    highlightedValuesDisplayMode?: SeriesHighlightedValuesDisplayMode | string;
    /**
     * Gets or sets a set of property paths that should be included for consideration by the category chart, leaving the remainder excluded. If null, all properties will be considered.
    */
    includedProperties?: string[];
    /**
     * Gets the current set of valid visualization types for the data.
    */
    validVisualizationTypes?: DashboardTileVisualizationType[];
    /**
     * Gets or sets a set of property paths that should be excluded from consideration by the category chart.
    */
    excludedProperties?: string[];
    /**
     * Gets or sets the palette of brushes to use for coloring the dashboard tile.
     * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
    */
    brushes?: string[] | string;
    /**
     * Gets or sets the palette of brushes to use for outlines on the dashboard tile.
     * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
    */
    outlines?: string[] | string;
    /**
     * Gets the currently selected data items.  Adding or removing data items from this collection will
     * select or deselect the visuals associated with those items.
    */
    selectedSeriesItems?: IgrChartSelectedItemCollection | string;
    /**
     * Gets the actual palette of brushes to use for coloring the chart series.
    */
    actualBrushes?: string[] | string;
    /**
     * Gets the actual palette of brushes to use for outlines on the chart series.
    */
    actualOutlines?: string[] | string;
    /**
     * Gets the brush to use for the Category axis major strokes, if applicable.
    */
    categoryAxisMajorStroke?: string;
    /**
     * Gets or sets what value lines to use in the chart.
    */
    valueLines?: IgrValueModeCollection | string;
    /**
     * Gets or sets the palette of brushes to use for coloring the value lines present in the ValueLines property.
     * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
    */
    valueLinesBrushes?: string[] | string;
    /**
     * Gets or sets if the auto value callouts should be displayed.
    */
    autoCalloutsVisible?: boolean | string;
    /**
     * Gets or sets whether annotations are shown along the axis for crosshair values
    */
    crosshairsAnnotationEnabled?: boolean | string;
    /**
     * Gets or sets whether annotations for the final value of each series is displayed on the axis.
    */
    finalValueAnnotationsVisible?: boolean | string;
    /**
     * Gets or sets the crosshairs to be displayed.
    */
    crosshairsDisplayMode?: CrosshairsDisplayMode | string;
    /**
     * Gets or sets the crosshairs to be displayed.
    */
    visualizationType?: DashboardTileVisualizationType | string;
    /**
     * Gets or sets the crosshairs to be displayed.
    */
    validVisualizationTypePriorityThreshold?: number | string;
    /**
     * Gets or sets the base built in theme to use for the checkbox.
    */
    baseTheme?: BaseControlTheme | string;
    /**
     * Gets or sets the display density to use for the toolbar.
    */
    density?: ControlDisplayDensity | string;
    /**
     * Gets or sets the color to use for the background of the component.
    */
    backgroundColor?: string;
    changingContent?: (s: IgrDashboardTile, e: IgrDashboardTileChangingContentEventArgs) => void;
    filterStringErrorsParsing?: (s: IgrDashboardTile, e: IgrDashboardTileFilterStringErrorsParsingEventArgs) => void;
}
